@@ -4,6 +4,7 @@ import pathlib
 
 config_path = '/etc'
 config_path_alternate = os.path.join(os.path.expanduser("~"), '.config')
+config_path_windows = os.getenv('APPDATA')
 
 
 class Config(object):
@@ -13,7 +14,8 @@ class Config(object):
             file='example.cfg',
             cfg_dir_name='example_config_dir',
             local=False,
-            dir_path=None
+            dir_path=None,
+            sort_keys=False
     ):
         global config_path
         if std_config is None:
@@ -29,18 +31,24 @@ class Config(object):
         else:
             if dir_path:
                 config_path = dir_path
-            self.dir_path = config_path
+            if os.name == 'posix':
+                self.dir_path = config_path
+            elif os.name == 'nt':
+                self.dir_path = config_path_windows
+            else:
+                raise RuntimeError('Unsupported platform: %s' % os.name)
+        self.sort_keys = sort_keys
 
-    def import_config(self):
+    def import_config(self, alternate=False):
         full_path = os.path.join(self.dir_path, self.cfg_dir_name, self.file)
         if not os.path.isfile(full_path):
-            if self.dir_path == config_path_alternate:
-                self.dir_path = config_path
+            if alternate:
+                # self.dir_path = config_path
                 self.generate_config()
                 full_path = os.path.join(self.dir_path, self.cfg_dir_name, self.file)
             else:
-                self.dir_path = config_path_alternate
-                return self.import_config()
+                # self.dir_path = config_path_alternate
+                return self.import_config(alternate=True)
         with open(full_path, 'r') as f:
             load_config_data = json.loads(f.read())
         # self.std_config = self.get_std_config()
@@ -53,17 +61,16 @@ class Config(object):
             self.update_config(full_path, load_config_data)
         return load_config_data
 
-    @staticmethod
-    def update_config(path, c_data):
+    def update_config(self, path, c_data):
         with open(path, 'w') as f:
-            f.write(json.dumps(c_data, indent=4))
+            f.write(json.dumps(c_data, indent=4, sort_keys=self.sort_keys))
 
     def generate_config(self):
         full_path = os.path.join(self.dir_path, self.cfg_dir_name, self.file)
         try:
             os.makedirs(os.path.dirname(full_path), exist_ok=True)
             with open(full_path, 'w') as f:
-                f.write(json.dumps(self.std_config, indent=4))
+                f.write(json.dumps(self.std_config, indent=4, sort_keys=self.sort_keys))
         except PermissionError:
             self.dir_path = config_path_alternate
             return self.generate_config()
